@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: SQLite setup/teardown for tests
 
-our $VERSION = '0.0200';
+our $VERSION = '0.0201';
 
 use Moo;
 use strictures 2;
@@ -81,7 +81,7 @@ sub _build__database {
 
             $sql .= $line;
 
-            if ( $line =~ /;/ ) {
+            if ( $line =~ /;\s*$/ ) {
                 $dbh->do($sql)
                     or die 'Error executing SQL for ' . $self->schema . ': ' . $dbh->errstr;
 
@@ -120,21 +120,21 @@ Test::SQLite - SQLite setup/teardown for tests
 
 =head1 VERSION
 
-version 0.0200
+version 0.0201
 
 =head1 SYNOPSIS
 
   use DBI;
   use Test::SQLite;
 
-  my $sqlite = Test::SQLite->new(
-    database => '/some/where/production.db',
-    db_attrs => { RaiseError => 1, AutoCommit => 0 },
-  );
+  my $sqlite = Test::SQLite->new(database => '/some/where/production.db');
 
   my $dbh = $sqlite->dbh;
 
-  $sqlite = Test::SQLite->new(schema => '/some/where/schema.sql');
+  $sqlite = Test::SQLite->new(
+    schema   => '/some/where/schema.sql',
+    db_attrs => { RaiseError => 1, AutoCommit => 0 },
+  );
 
   $dbh = DBI->connect($sqlite->dsn, '', '', $sqlite->db_attrs);
 
